##  Add Fact Sheet Owners
Now is the time to ensure that you have filled out the subscriptions for these applications. In the next phase, you will need these contacts to send surveys for the application rationalization assessment.
Learn more about subscriptions at [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
  1. Open the inventory in the table view.
  2. Display the columns Responsible and enable Responsible: Application Owner and Responsible: Technical Expert.
![Screenshot showing the inventory in table view and activating the columns for responsible](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioebd530f755074695bac76d008e2fd785_LowRes.png)
  3. Click Edit at the top of the inventory. If there are empty fields for Application Owner or Technical Expert, fill in the email address.
![Screenshot of the inventory in table view showing how to edit the responsible field and adding an email address](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio733fc9a56b564fedbbd04300615549a6_HiRes.png)
